@@ -58,7 +58,9 @@ class CorpusManager(object):
     def load_from_wb_database(self, db_name: str, db_user: str, db_password: str, db_host: str,
                               tazendra_ssh_user: str = None, tazendra_ssh_passwd: str = None, paper_ids: list = None,
                               from_date: str = None, load_pdf_files: bool = True, load_bib_info: bool = True,
-                              load_curation_info: bool = True, max_num_papers: int = None) -> None:
+                              load_curation_info: bool = True, max_num_papers: int = None,
+                              exclude_ids: List[str] = None, must_have_svm: bool = False,
+                              exclude_pap_types: List[str] = None) -> None:
         """load papers from WormBase database
 
         Args:
@@ -74,19 +76,27 @@ class CorpusManager(object):
             load_bib_info (bool): load bibliographic info of the papers
             load_curation_info (bool): load curation info of the papers
             max_num_papers (int): limit number of papers to be loaded
+            exclude_ids (List[str]): list of paper ids to exclude
+            must_have_svm (bool): whether to load only papers that have been flagged by WB SVMs
+            exclude_pap_types (List[str]): list of pap_types (string value, not numeric) to exclude
         """
+        db_manager = WBDBManager(db_name, db_user, db_password, db_host)
         if not paper_ids:
-            db_manager = WBDBManager(db_name, db_user, db_password, db_host)
-            paper_ids = db_manager.generic.get_all_paper_ids(added_or_modified_after=from_date)
+            paper_ids = db_manager.generic.get_all_paper_ids(added_or_modified_after=from_date, exclude_ids=exclude_ids)
+        if exclude_pap_types:
+            ids_to_exclude = db_manager.generic.get_paper_ids_with_pap_types(exclude_pap_types)
+            paper_ids = list(set(paper_ids) - set(ids_to_exclude))
         for paper_id in paper_ids:
             paper = WBPaper(paper_id=paper_id, tazendra_ssh_user=tazendra_ssh_user,
                             tazendra_ssh_passwd=tazendra_ssh_passwd)
-            if load_pdf_files:
-                paper.load_text_from_pdf_files_in_db(db_name=db_name, db_user=db_user, db_password=db_password,
-                                                     db_host=db_host)
             if load_curation_info:
                 paper.load_curation_info_from_db(db_name=db_name, db_user=db_user, db_password=db_password,
                                                  db_host=db_host)
+                if must_have_svm and not paper.svm_values:
+                    continue
+            if load_pdf_files:
+                paper.load_text_from_pdf_files_in_db(db_name=db_name, db_user=db_user, db_password=db_password,
+                                                     db_host=db_host)
             if load_bib_info:
                 paper.load_bib_info_from_db(db_name=db_name, db_user=db_user, db_password=db_password, db_host=db_host)
             self.add_or_update_wb_paper(paper)
@@ -170,7 +180,7 @@ class CorpusManager(object):
     def query_papers_by_doc_similarity(self, query_docs: List[str], sentence_search: bool = False,
                                        remove_sections: List[PaperSections] = None,
                                        must_be_present: List[PaperSections] = None, path_to_model: str = None,
-                                       average_match: bool = True) -> List[SimilarityResult]:
+                                       average_match: bool = True, num_best: int = 10) -> List[SimilarityResult]:
         """query papers in the corpus by similarity with the provided query documents, which can be fulltext documents
            or sentences
 
@@ -182,6 +192,7 @@ class CorpusManager(object):
                                                    sections
             path_to_model (str): path to word2vec model
             average_match (bool): merge query documents and calculate average similarity to them
+            num_best (int): limit to the first n results by similarity score
 
         Returns:
             List[SimilarityResult]: list of papers most similar to the provided query documents
@@ -194,12 +205,13 @@ class CorpusManager(object):
             split_sentences=sentence_search, remove_sections=remove_sections, must_be_present=must_be_present,
             lowercase=False, tokenize=False, remove_stopwords=False, remove_alpha=False)
         docsim_index, dictionary = get_softcosine_index(model=model, model_path=path_to_model,
-                                                        corpus_list_token=corpus_list_token)
+                                                        corpus_list_token=corpus_list_token, num_best=num_best)
         query_docs_preprocessed = [preprocess(doc=sentence, lower=True, tokenize=True, remove_stopwords=True,
                                               remove_alpha=True) for sentence in query_docs]
         sims = get_similar_documents(docsim_index, dictionary, query_docs_preprocessed, idx_paperid_map,
                                      average_match=average_match)
-        return [SimilarityResult(score=sim.score, paper_id=sim.paper_id, match_idx=sim.match_idx,
-                                 query_idx=sim.query_idx, match="\"" + corpus_list_token_orig[sim.match_idx] + "\"",
-                                 query="\"" + (" ".join(query_docs) if average_match else query_docs[sim.query_idx]) +
-                                       "\"") for sim in sims]
+        results = [SimilarityResult(score=sim.score, paper_id=sim.paper_id, match_idx=sim.match_idx,
+                                    query_idx=sim.query_idx, match="\"" + corpus_list_token_orig[sim.match_idx] + "\"",
+                                    query="\"" + (" ".join(query_docs) if average_match else query_docs[sim.query_idx]
+                                                  ) + "\"") for sim in sims]
+        return results[0:num_best] if len(results) > num_best else results
